@@ -25,8 +25,10 @@ class Background:
             os.system('rm -r {0}'.format(savefolder))
             print('Remove {0}'.format(savefolder))
         else:
+            tmp = os.getcwd()
             try:
                 os.chdir(savefolder)
+                os.chdir(tmp)
                 print('Stop: Savefolder {0} already exists, overwrite = {1}'.format(savefolder,overwrite))
                 return
             except:
