@@ -27,7 +27,7 @@ class Wfc3IrG102:
                      'ROOTNAME':None,
                      'NAXIS1':None,
                      'NAXIS2':None,
-                     'xgbound':(0.,250.)
+                     'xgbound':(-65.,250.)
                     }
         self.conf = None
         self.trace = {'XYREF':(None,None),
